#line 2 "wimaxasncp_dict.c"

#line 4 "wimaxasncp_dict.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer WimaxasncpDict_create_buffer
#define yy_delete_buffer WimaxasncpDict_delete_buffer
#define yy_flex_debug WimaxasncpDict_flex_debug
#define yy_init_buffer WimaxasncpDict_init_buffer
#define yy_flush_buffer WimaxasncpDict_flush_buffer
#define yy_load_buffer_state WimaxasncpDict_load_buffer_state
#define yy_switch_to_buffer WimaxasncpDict_switch_to_buffer
#define yyin WimaxasncpDictin
#define yyleng WimaxasncpDictleng
#define yylex WimaxasncpDictlex
#define yylineno WimaxasncpDictlineno
#define yyout WimaxasncpDictout
#define yyrestart WimaxasncpDictrestart
#define yytext WimaxasncpDicttext
#define yywrap WimaxasncpDictwrap
#define yyalloc WimaxasncpDictalloc
#define yyrealloc WimaxasncpDictrealloc
#define yyfree WimaxasncpDictfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE WimaxasncpDictrestart(WimaxasncpDictin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int WimaxasncpDictleng;

extern FILE *WimaxasncpDictin, *WimaxasncpDictout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up WimaxasncpDicttext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up WimaxasncpDicttext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via WimaxasncpDictrestart()), so that the user can continue scanning by
	 * just pointing WimaxasncpDictin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when WimaxasncpDicttext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int WimaxasncpDictleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow WimaxasncpDictwrap()'s to do buffer switches
 * instead of setting up a fresh WimaxasncpDictin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void WimaxasncpDictrestart (FILE *input_file  );
void WimaxasncpDict_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE WimaxasncpDict_create_buffer (FILE *file,int size  );
void WimaxasncpDict_delete_buffer (YY_BUFFER_STATE b  );
void WimaxasncpDict_flush_buffer (YY_BUFFER_STATE b  );
void WimaxasncpDictpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void WimaxasncpDictpop_buffer_state (void );

static void WimaxasncpDictensure_buffer_stack (void );
static void WimaxasncpDict_load_buffer_state (void );
static void WimaxasncpDict_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER WimaxasncpDict_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE WimaxasncpDict_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE WimaxasncpDict_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE WimaxasncpDict_scan_bytes (yyconst char *bytes,int len  );

void *WimaxasncpDictalloc (yy_size_t  );
void *WimaxasncpDictrealloc (void *,yy_size_t  );
void WimaxasncpDictfree (void *  );

#define yy_new_buffer WimaxasncpDict_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        WimaxasncpDictensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            WimaxasncpDict_create_buffer(WimaxasncpDictin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        WimaxasncpDictensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            WimaxasncpDict_create_buffer(WimaxasncpDictin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *WimaxasncpDictin = (FILE *) 0, *WimaxasncpDictout = (FILE *) 0;

typedef int yy_state_type;

extern int WimaxasncpDictlineno;

int WimaxasncpDictlineno = 1;

extern char *WimaxasncpDicttext;
#define yytext_ptr WimaxasncpDicttext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up WimaxasncpDicttext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	WimaxasncpDictleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 60
#define YY_END_OF_BUFFER 61
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[326] =
    {   0,
        0,    0,   24,   24,    0,    0,    7,    7,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   30,   30,
       31,   31,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   61,   60,   27,   24,   24,   27,
       27,   27,   20,   26,   21,   27,    4,    4,   60,    4,
        7,    8,   16,   60,   60,   18,   60,   29,   30,   30,
       30,   30,   60,   31,   31,   31,   31,   60,   38,   33,
       35,   37,   39,   40,   59,   59,   60,   60,   60,   41,

       41,   60,   60,   54,   60,   60,   60,   49,   60,   60,
       60,   13,   13,   60,   13,   13,   13,   10,   12,   24,
        0,   20,   26,   21,    0,    0,   25,    0,   22,   20,
        0,   23,    6,   26,   21,    0,    2,    0,    0,    0,
        7,    8,   16,    0,    0,    0,   18,    0,   19,   29,
       30,   30,   30,   30,    0,   31,   31,   31,   31,    0,
       38,   33,   35,   37,   39,    0,    0,    0,    0,    0,
        0,   42,    0,   58,   55,    0,    0,   50,    0,    0,
        0,    0,    0,    0,    0,   14,    0,    0,   10,   12,
       28,   22,    0,    0,    0,   23,    6,    2,    5,    0,

       19,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   14,    0,    0,    3,    0,    0,    5,
        0,    0,    0,    0,   44,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    3,    0,    0,    0,
        0,    0,    0,    0,   51,   58,   58,    0,    0,   58,
       58,    0,    9,    0,    0,    0,    0,    0,    0,    0,
       56,   53,   52,    0,    0,   45,   47,    0,    0,    0,
        0,    0,   17,    0,    0,    0,    0,    0,    0,   11,
        0,   15,    0,    0,    0,   58,    0,    0,   15,    0,
        0,    0,   48,    0,    0,    1,    0,    0,    0,    0,

        1,    0,    0,    0,    0,    0,   43,    0,   58,    0,
       57,   46,    0,    0,    0,    0,    0,    0,    0,   36,
        0,   34,    0,   32,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    1,    1,    1,    7,    1,    8,
        9,    1,    1,    1,   10,    1,   11,   12,   13,   14,
       15,   16,   16,   17,   16,   18,   16,    1,   19,   20,
       21,   22,   23,    1,   24,   25,   26,   27,   28,   29,
       30,   30,   31,   30,   32,   33,   34,   35,   36,   37,
       30,   38,   39,   40,   41,   42,   43,   44,   45,   30,
       46,    1,   47,    1,   48,    1,   49,   50,   51,   52,

       53,   29,   30,   30,   54,   30,   55,   56,   57,   58,
       59,   60,   30,   61,   62,   63,   64,   65,   66,   67,
       68,   30,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[69] =
    {   0,
        1,    1,    1,    1,    1,    2,    1,    1,    1,    3,
        1,    3,    3,    3,    3,    3,    3,    3,    1,    1,
        4,    1,    1,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    1,    1,    1,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3
    } ;

static yyconst flex_int16_t yy_base[352] =
    {   0,
        0,    0,    0,    6,   21,   30,   53,  101,  149,  197,
       75,   78,  640,  639,  627,  610,  598,  593,  236,    0,
      293,    0,  116,  164,  212,  257,  281,  314,  588,  560,
      559,  548,   15,   16,    9,   23,    0,    0,  515,  510,
       35,   36,  346,  404,  406,  409,  471,  474,  515,  514,
      495,  481,    0,    0,  466, 1063, 1063,  478,  520,  441,
        0,  399,  359,   42,   46,   63, 1063,   84,   87,  406,
       66,    0,    0,  229,   47,    0,  139,    0,  171,  556,
       49,  531,   65,  222,  612,   69,  543,  136, 1063,  321,
      361,  371,    0, 1063, 1063,  112,    0,  152,  390, 1063,

      384,  350,  334, 1063,  154,  291,  319, 1063,  401,  416,
      236, 1063,  589,  611,  292,  194,  218,    0,    0,  575,
      291,  481,  207,  274,  505,  286, 1063,  265,  356,  396,
      443,  508,  515,  530,  548,  645,  560,  648,  272,  236,
      586,    0,    0,  616,   99,  262,    0,  666,  599,    0,
      668,  336,    0,    0,  357,  677,  352,    0,    0,  393,
     1063,  684,  691,  698,    0,  414,  228,  423,  451,  470,
      250, 1063,  220, 1063, 1063,  590,  481, 1063,  696,  697,
      516,  717,  201,  272,  410,  669,  678,  692,    0,    0,
     1063,  724,  202,  693,  695,  730,  734,  739,  753,  699,

      761,  414,  606,  713,  703,  717,  710,  748,  749,  739,
      740,  750,  758,  781,  785,  740,  790,  609,  750,  793,
      752,  755,  760,  781, 1063,  766,  776,  186,  173,  788,
      791,  172,  170,  814,  822,  786,  817,  787,  799,  800,
      812,  806,  801,  152, 1063,  156,  140,  817,  823,  129,
      121,  845, 1063,  863,  801,  815,  869,  817,  822,  828,
     1063, 1063, 1063,  842,  853, 1063, 1063,  883,  889,  839,
      838,  894, 1063,  853,  854,  858,  105,  880,  912, 1063,
      815,  905,  876,  881,  875,  105,  898,   52,  919,  887,
      887,  902, 1063,  910,   49,  932,   36,  887,  899,  907,

      936,  916,   61,  899,   50,  914, 1063,   41,   46,  909,
     1063, 1063,  475,   34,   23,  157,  440,  948,  951, 1063,
      955, 1063,  956, 1063, 1063,  972,  976,  980,  984,  988,
      992,  996, 1000, 1004, 1008, 1012, 1016, 1020, 1024, 1028,
       12,   11,    2, 1032, 1036, 1040, 1044, 1046, 1050, 1054,
     1058
    } ;

static yyconst flex_int16_t yy_def[352] =
    {   0,
      326,  326,  327,  327,  328,  328,  329,  329,  330,  330,
      326,  326,  331,  331,  326,  326,  332,  332,  326,   19,
      326,   21,  326,  326,  326,  326,  326,  326,  333,  333,
      326,  326,  334,  334,  326,  326,  326,  326,  326,  326,
      335,  335,  336,  336,   44,   44,  337,  337,  338,  338,
      339,  339,  326,  326,  325,  325,  325,  325,  325,  340,
      341,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  342,  343,  325,  325,  344,  325,  345,  325,  325,
       80,   80,  325,  325,  325,   85,   85,  325,  325,  325,
      325,  325,  346,  325,  325,  325,  341,  325,  325,  325,

      347,  348,  325,  325,  348,  348,  325,  325,  348,  348,
      348,  325,  325,  325,  325,  325,  325,  349,  350,  325,
      325,  325,  325,  325,  325,  340,  325,  341,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  342,  343,  325,  325,  325,  344,  325,  325,  345,
      325,   80,   82,   82,  325,  325,   85,   87,   87,  325,
      325,  325,  325,  325,  346,  325,  325,  325,  325,  325,
      347,  325,  348,  325,  325,  348,  348,  325,  348,  348,
      348,  325,  325,  325,  325,  325,  325,  325,  349,  350,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,

      325,  325,  325,  325,  325,  325,  325,  348,  348,  348,
      348,  348,  348,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  348,  348,  348,
      348,  348,  348,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  348,  348,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  348,  348,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  348,  348,  325,  325,
      325,  325,  325,  325,  325,  325,  348,  351,  325,  325,
      325,  325,  325,  348,  351,  325,  325,  325,  325,  348,

      325,  325,  325,  325,  348,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,    0,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325
    } ;

static yyconst flex_int16_t yy_nxt[1132] =
    {   0,
      325,   58,   59,   58,  143,   60,   61,   58,   59,   58,
       62,   60,   61,  142,  128,   97,   62,   56,   56,   63,
       64,   65,   68,   69,   68,   63,   64,   65,   98,   97,
       70,   68,   69,   68,   96,   96,  318,   56,   56,   70,
      101,  101,   98,  134,  134,  134,   66,  135,  135,  135,
      317,  312,   66,   56,   71,   71,   71,   56,   56,   56,
       56,   56,  311,   56,  136,  136,  136,  141,  141,  141,
      309,   56,   56,   56,   56,   56,   74,   74,   74,   74,
       74,   74,  307,  302,  137,  138,  138,  138,  138,  138,
      138,  146,  325,  139,  296,  155,  139,  296,   56,   56,

       56,   56,   71,   71,   71,   56,   56,   56,   56,   56,
      293,   56,  325,   75,  146,  325,   75,   88,  155,   56,
       56,   56,   56,   56,   89,  286,  267,   90,   90,   90,
       90,   90,   90,   90,  266,  325,   75,  160,  166,   75,
      148,  148,  148,  146,  161,  263,   56,   56,   56,   56,
       56,   56,   56,   56,   56,   56,   56,   56,  319,   56,
      149,  262,  167,  166,  320,   88,  146,   56,   56,   56,
       56,   56,   89,  261,  174,   90,   90,   90,   90,   90,
       90,   90,  151,  151,  151,  151,  151,  151,  151,  176,
      251,  168,  250,  247,   56,   56,   56,   56,   56,   56,

       56,   56,   56,   56,   56,   56,  246,   56,  134,  134,
      134,  217,  176,   88,  168,   56,   56,   56,   56,   56,
       89,  187,  186,   91,   91,   91,   91,   91,   91,   91,
      144,  144,  144,  156,  156,  156,  156,  156,  156,  156,
      174,  188,   56,   56,   56,   79,  187,   80,   81,   81,
       81,   81,   81,   81,  204,  172,  174,  199,   88,   82,
       82,   82,   82,   82,   82,   89,  188,  145,   91,   91,
       91,   91,   91,   91,   91,  135,  135,  135,   83,  204,
      181,  140,   88,  191,   82,   82,   82,   82,   82,   89,
      145,  127,   92,   92,   92,   92,   92,   92,   92,  187,

      200,   83,   84,  181,   85,   86,   86,   86,   86,   86,
       86,  174,  129,  186,  177,   88,   87,   87,   87,   87,
       87,   87,   89,  200,  187,   92,   92,   92,   92,   92,
       92,   92,  162,  162,  162,  162,  162,  162,  162,  177,
      178,   87,   87,   87,   87,   87,   56,   56,   56,   56,
       56,   56,   56,   56,   56,  175,  103,  192,  192,  192,
      130,  130,  130,  131,   56,   56,   56,  104,   56,  132,
      174,  105,  163,  163,  163,  163,  163,  163,  163,  325,
      106,  133,  164,  164,  164,  164,  164,  164,  164,  172,
      202,   56,   56,   56,  160,  325,  105,  130,  130,  130,

      169,  161,  325,  106,   56,   56,   56,   56,   56,   56,
       56,   56,   56,  202,  103,  140,  107,  170,  325,  107,
      129,  174,   56,   56,   56,  104,   56,  108,  179,  105,
      108,  102,  109,  188,  102,  109,  174,  222,  106,  180,
      110,  321,  170,  110,  203,  111,  127,  322,  111,   56,
       56,   56,  193,  179,  105,  205,  102,  109,  188,  102,
      109,  106,  222,  110,  180,  325,  110,  203,  111,  194,
      195,  111,  113,  114,  113,  113,  114,  113,  205,  120,
      120,  120,  130,  130,  130,  131,   56,  314,  121,  315,
      206,  132,  316,  115,  194,  195,  115,  122,  123,  124,

       56,  174,  116,  133,  207,  116,  136,  136,  136,  196,
      196,  196,  117,  206,  209,  117,  197,  197,  197,   56,
       56,  120,  120,  120,  125,  116,  137,  207,  116,   99,
      121,  134,  134,  134,   99,  117,  174,  209,  117,  122,
      123,  124,  153,  153,  153,  153,  153,  153,  153,  135,
      135,  135,  213,   94,  158,  158,  158,  158,  158,  158,
      158,  198,  198,  198,   94,   56,  125,  152,  152,  152,
      152,  152,  152,  152,  325,  213,  120,  120,  120,  153,
      153,  153,  153,  153,  153,  121,  325,  141,  141,  141,
      182,  182,  182,   56,  122,  123,  124,  325,   56,  154,

      201,  201,  201,   56,  153,  153,  153,  153,  153,  325,
      174,  183,  182,  182,  182,   77,  208,  144,  144,  144,
      184,  125,  154,  157,  157,  157,  157,  157,  157,  157,
      185,  223,   77,  183,  238,  158,  158,  158,  158,  158,
      158,  208,  184,  184,   56,   56,  136,  136,  136,  138,
      138,  138,  185,  185,  145,  159,  223,  139,  325,  238,
      158,  158,  158,  158,  158,  184,  137,  148,  148,  148,
      214,  214,  214,  325,  325,  185,  325,  145,  159,  151,
      151,  151,  151,  151,  151,  151,  325,  149,  156,  156,
      156,  156,  156,  156,  156,  162,  162,  162,  162,  162,

      162,  162,  163,  163,  163,  163,  163,  163,  163,  164,
      164,  164,  164,  164,  164,  164,  174,  174,  182,  182,
      182,  210,  215,  325,  216,  192,  192,  192,  218,  219,
      212,  196,  196,  196,  211,  197,  197,  197,  221,  183,
      198,  198,  198,  224,  225,  215,  210,  216,  184,  226,
      227,  218,  219,  212,  220,  220,  220,  211,  185,  174,
      174,  221,  201,  201,  201,  231,  224,  225,  174,  174,
      174,  184,  226,  227,  230,  228,  229,  232,  174,  240,
      236,  185,  214,  214,  214,  233,  234,  234,  234,  239,
      231,  237,  237,  237,  220,  220,  220,  230,  241,  242,

      228,  229,  232,  236,  240,  235,  243,  244,  174,  245,
      233,  174,  239,  254,  248,  234,  234,  234,  237,  237,
      237,  241,  242,  252,  252,  252,  255,  253,  249,  256,
      244,  243,  245,  257,  235,  258,  259,  174,  254,  248,
      260,  325,  288,  174,  264,  270,  252,  252,  252,  255,
      253,  249,  256,  265,  271,  274,  257,  275,  276,  259,
      258,  325,  174,  260,  268,  268,  268,  288,  270,  264,
      272,  272,  272,  174,  273,  281,  265,  271,  274,  277,
      275,  276,  282,  269,  268,  268,  268,  283,  284,  278,
      279,  279,  279,  285,  280,  272,  272,  272,  281,  273,

      174,  290,  277,  269,  291,  282,  289,  289,  289,  292,
      283,  284,  278,  279,  279,  279,  285,  280,  174,  287,
      289,  289,  289,  297,  298,  299,  290,  174,  294,  291,
      174,  303,  292,  301,  301,  301,  304,  301,  301,  301,
      306,  305,  287,  308,  310,  300,  297,  298,  313,  323,
      299,  294,  319,  325,  303,  324,  321,  323,  320,  304,
      325,  325,  322,  324,  305,  306,  308,  310,  300,  325,
      325,  313,   56,   56,   56,   56,   57,   57,   57,   57,
       67,   67,   67,   67,   72,   72,   72,   72,   73,   73,
       73,   73,   76,   76,   76,   76,   78,   78,   78,   78,

       93,   93,   93,   93,   95,   95,   95,   95,  100,  100,
      100,  100,  102,  102,  102,  102,  112,  112,  112,  112,
      118,  118,  118,  118,  119,  119,  119,  119,  126,  126,
      126,  126,  147,  325,  147,  147,  150,  325,  150,  150,
      165,  325,  165,  165,  171,  171,  171,  171,  173,  173,
      189,  325,  189,  189,  190,  325,  190,  190,  295,  295,
      295,  295,   55,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,

      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325
    } ;

static yyconst flex_int16_t yy_chk[1132] =
    {   0,
        0,    3,    3,    3,  343,    3,    3,    4,    4,    4,
        3,    4,    4,  342,  341,   35,    4,   33,   34,    3,
        3,    3,    5,    5,    5,    4,    4,    4,   35,   36,
        5,    6,    6,    6,   33,   34,  315,   41,   42,    6,
       41,   42,   36,   64,   64,   64,    3,   65,   65,   65,
      314,  309,    4,    7,    7,    7,    7,    7,    7,    7,
        7,    7,  308,    7,   66,   66,   66,   71,   71,   71,
      305,    7,    7,    7,    7,    7,   11,   11,   11,   12,
       12,   12,  303,  297,   66,   68,   68,   68,   69,   69,
       69,   75,   81,   68,  295,   83,   69,  288,    7,    7,

        7,    8,    8,    8,    8,    8,    8,    8,    8,    8,
      286,    8,   86,   11,   75,   81,   12,   23,   83,    8,
        8,    8,    8,    8,   23,  277,  251,   23,   23,   23,
       23,   23,   23,   23,  250,   86,   11,   88,   96,   12,
       77,   77,   77,  145,   88,  247,    8,    8,    8,    9,
        9,    9,    9,    9,    9,    9,    9,    9,  316,    9,
       77,  246,   98,   96,  316,   24,  145,    9,    9,    9,
        9,    9,   24,  244,  105,   24,   24,   24,   24,   24,
       24,   24,   79,   79,   79,   79,   79,   79,   79,  105,
      233,   98,  232,  229,    9,    9,    9,   10,   10,   10,

       10,   10,   10,   10,   10,   10,  228,   10,  123,  123,
      123,  193,  105,   25,   98,   10,   10,   10,   10,   10,
       25,  116,  183,   25,   25,   25,   25,   25,   25,   25,
       74,   74,   74,   84,   84,   84,   84,   84,   84,   84,
      173,  117,   10,   10,   10,   19,  116,   19,   19,   19,
       19,   19,   19,   19,  167,  171,  111,  140,   26,   19,
       19,   19,   19,   19,   19,   26,  117,   74,   26,   26,
       26,   26,   26,   26,   26,  124,  124,  124,   19,  167,
      111,  139,   27,  128,   19,   19,   19,   19,   19,   27,
       74,  126,   27,   27,   27,   27,   27,   27,   27,  184,

      146,   19,   21,  111,   21,   21,   21,   21,   21,   21,
       21,  106,  121,  115,  106,   28,   21,   21,   21,   21,
       21,   21,   28,  146,  184,   28,   28,   28,   28,   28,
       28,   28,   90,   90,   90,   90,   90,   90,   90,  106,
      107,   21,   21,   21,   21,   21,   43,   43,   43,   43,
       43,   43,   43,   43,   43,  103,   43,  129,  129,  129,
       63,   63,   63,   63,   43,   43,   43,   43,   43,   63,
      102,   43,   91,   91,   91,   91,   91,   91,   91,  152,
       43,   63,   92,   92,   92,   92,   92,   92,   92,  101,
      155,   43,   43,   43,  160,  157,   43,  130,  130,  130,

       99,  160,  152,   43,   44,   44,   44,   44,   44,   44,
       44,   44,   44,  155,   44,   70,   45,   99,  157,   46,
       62,  109,   44,   44,   44,   44,   44,   45,  109,   44,
       46,   45,   45,  185,   46,   46,  110,  202,   44,  110,
       45,  317,   99,   46,  166,   45,   60,  317,   46,   44,
       44,   44,  131,  109,   44,  168,   45,   45,  185,   46,
       46,   44,  202,   45,  110,   55,   46,  166,   45,  131,
      131,   46,   47,   47,   47,   48,   48,   48,  168,   58,
       58,   58,  122,  122,  122,  122,   52,  313,   58,  313,
      169,  122,  313,   47,  131,  131,   48,   58,   58,   58,

       51,  177,   47,  122,  170,   48,  125,  125,  125,  132,
      132,  132,   47,  169,  177,   48,  133,  133,  133,   50,
       49,   59,   59,   59,   58,   47,  125,  170,   48,   40,
       59,  134,  134,  134,   39,   47,  181,  177,   48,   59,
       59,   59,   82,   82,   82,   82,   82,   82,   82,  135,
      135,  135,  181,   32,   87,   87,   87,   87,   87,   87,
       87,  137,  137,  137,   31,   30,   59,   80,   80,   80,
       80,   80,   80,   80,   82,  181,  120,  120,  120,   80,
       80,   80,   80,   80,   80,  120,   87,  141,  141,  141,
      113,  113,  113,   29,  120,  120,  120,   82,   18,   80,

      149,  149,  149,   17,   80,   80,   80,   80,   80,   87,
      176,  113,  114,  114,  114,   16,  176,  144,  144,  144,
      113,  120,   80,   85,   85,   85,   85,   85,   85,   85,
      113,  203,   15,  114,  218,   85,   85,   85,   85,   85,
       85,  176,  114,  113,   14,   13,  136,  136,  136,  138,
      138,  138,  114,  113,  144,   85,  203,  138,    0,  218,
       85,   85,   85,   85,   85,  114,  136,  148,  148,  148,
      186,  186,  186,    0,    0,  114,    0,  144,   85,  151,
      151,  151,  151,  151,  151,  151,    0,  148,  156,  156,
      156,  156,  156,  156,  156,  162,  162,  162,  162,  162,

      162,  162,  163,  163,  163,  163,  163,  163,  163,  164,
      164,  164,  164,  164,  164,  164,  179,  180,  182,  182,
      182,  179,  187,    0,  188,  192,  192,  192,  194,  195,
      180,  196,  196,  196,  179,  197,  197,  197,  200,  182,
      198,  198,  198,  204,  205,  187,  179,  188,  182,  206,
      207,  194,  195,  180,  199,  199,  199,  179,  182,  210,
      211,  200,  201,  201,  201,  211,  204,  205,  208,  209,
      212,  182,  206,  207,  210,  208,  209,  212,  213,  221,
      216,  182,  214,  214,  214,  213,  215,  215,  215,  219,
      211,  217,  217,  217,  220,  220,  220,  210,  222,  223,

      208,  209,  212,  216,  221,  215,  224,  226,  230,  227,
      213,  231,  219,  236,  230,  234,  234,  234,  237,  237,
      237,  222,  223,  235,  235,  235,  238,  235,  231,  239,
      226,  224,  227,  240,  234,  241,  242,  248,  236,  230,
      243,    0,  281,  249,  248,  255,  252,  252,  252,  238,
      252,  231,  239,  249,  256,  258,  240,  259,  260,  242,
      241,    0,  264,  243,  254,  254,  254,  281,  255,  248,
      257,  257,  257,  265,  257,  270,  249,  256,  258,  264,
      259,  260,  271,  254,  268,  268,  268,  274,  275,  265,
      269,  269,  269,  276,  269,  272,  272,  272,  270,  272,

      278,  283,  264,  268,  284,  271,  282,  282,  282,  285,
      274,  275,  265,  279,  279,  279,  276,  279,  287,  278,
      289,  289,  289,  290,  291,  292,  283,  300,  287,  284,
      294,  298,  285,  296,  296,  296,  299,  301,  301,  301,
      302,  300,  278,  304,  306,  294,  290,  291,  310,  318,
      292,  287,  319,    0,  298,  318,  321,  323,  319,  299,
        0,    0,  321,  323,  300,  302,  304,  306,  294,    0,
        0,  310,  326,  326,  326,  326,  327,  327,  327,  327,
      328,  328,  328,  328,  329,  329,  329,  329,  330,  330,
      330,  330,  331,  331,  331,  331,  332,  332,  332,  332,

      333,  333,  333,  333,  334,  334,  334,  334,  335,  335,
      335,  335,  336,  336,  336,  336,  337,  337,  337,  337,
      338,  338,  338,  338,  339,  339,  339,  339,  340,  340,
      340,  340,  344,    0,  344,  344,  345,    0,  345,  345,
      346,    0,  346,  346,  347,  347,  347,  347,  348,  348,
      349,    0,  349,  349,  350,    0,  350,  350,  351,  351,
      351,  351,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,

      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      325
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int WimaxasncpDict_flex_debug;
int WimaxasncpDict_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *WimaxasncpDicttext;
#line 1 "wimaxasncp_dict.l"
/*
 * We don't use unput, so don't generate code for it.
 */
/*
 * We don't read from the terminal.
 */
/*
 * The language we're scanning is case-insensitive.
 */
/*
 * We use start condition stacks.
 */
/*
 * Prefix scanner routines with "WimaxasncpDict" rather than "yy", so this
 * scanner can coexist with other scanners.
 */
#line 30 "wimaxasncp_dict.l"
	/*
	 ** wimaxasncp_dict.h
	 ** WIMAXASNCP Dictionary Import Routines
	 **
	 ** $Id: wimaxasncp_dict.l 32359 2010-04-02 06:03:44Z jake $
	 **
	 ** (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
	 ** (c) 2007, Stephen Croll <stephen.d.croll@gmail.com>
	 **
	 ** This library is free software; you can redistribute it and/or
	 ** modify it under the terms of the GNU Library General Public
	 ** License as published by the Free Software Foundation; either
	 ** version 2 of the License, or (at your option) any later version.
	 **
	 ** This library is distributed in the hope that it will be useful,
	 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
	 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	 ** Library General Public License for more details.
	 **
	 ** You should have received a copy of the GNU Library General Public
	 ** License along with this library; if not, write to the Free Software
	 ** Foundation, Inc., 51 Franklin Street, Fifth Floor,
	 ** Boston, MA  02110-1301, USA.
	 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <glib.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
#include <stdarg.h>
#include <epan/emem.h>
#include <epan/value_string.h>
#include <epan/packet.h>	/* array_length */
#include <wsutil/file_util.h>

#include "wimaxasncp_dict.h"
#include "wimaxasncp_dict_lex.h"

typedef struct entity_t {
	gchar *name;
	gchar *file;
	struct entity_t *next;
} entity_t;

#define ATTR_UINT(cont) do { D(("attr_uint " #cont "\t" )); attr_uint = &(cont); yy_push_state(GET_UINT_ATTR); } while(0)
#define ATTR_UINT16(cont) do { D(("attr_uint16 " #cont "\t" )); attr_uint16 = &(cont); yy_push_state(GET_UINT16_ATTR); } while(0)
#define ATTR_STR(cont) do { D(("attr_str " #cont "\t" )); attr_str = &(cont); yy_push_state(GET_ATTR); } while(0)
#define ATTR_DECODER(cont) do { D(("attr_decoder " #cont "\t" )); attr_uint = &(cont); yy_push_state(GET_DECODER_ATTR); } while(0)
#define WIMAXASNCP_IGNORE() do { D(("ignore: %s\t",WimaxasncpDicttext)); yy_push_state(IGNORE_ATTR); } while(0)

#define D(args) wimaxasncp_dict_debug args

#define MAX_INCLUDE_DEPTH 10
#define YY_INPUT(buf,result,max_size) { result = current_yyinput(buf,max_size); }
#define ECHO
#define APPEND(txt,len) append_to_buffer(txt,len)

static entity_t ents;
static YY_BUFFER_STATE include_stack[MAX_INCLUDE_DEPTH];
static int include_stack_ptr = 0;
static size_t (*current_yyinput)(gchar*,size_t);
static const gchar *sys_dir;
static wimaxasncp_dict_t *dict;
static wimaxasncp_dict_tlv_t *tlv;
static wimaxasncp_dict_enum_t *enumitem;
static wimaxasncp_dict_xmlpi_t *xmlpi;

static wimaxasncp_dict_tlv_t *last_tlv;
static wimaxasncp_dict_enum_t *last_enumitem;
static wimaxasncp_dict_xmlpi_t *last_xmlpi;

static gchar **attr_str;
static guint *attr_uint;
static gint16 *attr_uint16;

static guint wimaxasncp_bits(guint bits, char *n);
static gint wimaxasncp_decode_type(const gchar *name);
static void wimaxasncp_dict_debug(const gchar *fmt, ...);
static void append_to_buffer(gchar *txt, int len);
static FILE *wimaxasncp_dict_open(const gchar*, const gchar*);

static GString *dict_error = NULL;







#line 954 "wimaxasncp_dict.c"

#define INITIAL 0
#define LOADING 1
#define LOADING_COMMENT 2
#define LOADING_XMLPI 3
#define ENTITY 4
#define GET_SYSTEM 5
#define GET_FILE 6
#define END_ENTITY 7
#define GET_ATTR 8
#define GET_UINT_ATTR 9
#define GET_UINT16_ATTR 10
#define BIT32 11
#define BIT16 12
#define BIT8 13
#define GET_DECODER_ATTR 14
#define END_ATTR 15
#define OUTSIDE 16
#define IN_DICT 17
#define IN_APPL 18
#define IN_TLV 19
#define IGNORE_ATTR 20
#define ENUM_ATTRS 21
#define TLV_ATTRS 22
#define XMLPI_ATTRS 23
#define XMLPI_GETKEY 24
#define XMLPI_GETVAL 25
#define XMLPI_ENDATTR 26

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int WimaxasncpDictlex_destroy (void );

int WimaxasncpDictget_debug (void );

void WimaxasncpDictset_debug (int debug_flag  );

YY_EXTRA_TYPE WimaxasncpDictget_extra (void );

void WimaxasncpDictset_extra (YY_EXTRA_TYPE user_defined  );

FILE *WimaxasncpDictget_in (void );

void WimaxasncpDictset_in  (FILE * in_str  );

FILE *WimaxasncpDictget_out (void );

void WimaxasncpDictset_out  (FILE * out_str  );

int WimaxasncpDictget_leng (void );

char *WimaxasncpDictget_text (void );

int WimaxasncpDictget_lineno (void );

void WimaxasncpDictset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int WimaxasncpDictwrap (void );
#else
extern int WimaxasncpDictwrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state (int new_state );
    
    static void yy_pop_state (void );
    
    static int yy_top_state (void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( WimaxasncpDicttext, WimaxasncpDictleng, 1, WimaxasncpDictout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( WimaxasncpDictin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( WimaxasncpDictin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, WimaxasncpDictin))==0 && ferror(WimaxasncpDictin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(WimaxasncpDictin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int WimaxasncpDictlex (void);

#define YY_DECL int WimaxasncpDictlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after WimaxasncpDicttext and WimaxasncpDictleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 183 "wimaxasncp_dict.l"

#line 1177 "wimaxasncp_dict.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! WimaxasncpDictin )
			WimaxasncpDictin = stdin;

		if ( ! WimaxasncpDictout )
			WimaxasncpDictout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			WimaxasncpDictensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				WimaxasncpDict_create_buffer(WimaxasncpDictin,YY_BUF_SIZE );
		}

		WimaxasncpDict_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of WimaxasncpDicttext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 326 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 325 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 184 "wimaxasncp_dict.l"
;
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 185 "wimaxasncp_dict.l"
;
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 187 "wimaxasncp_dict.l"
BEGIN LOADING_COMMENT;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 188 "wimaxasncp_dict.l"
;
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 189 "wimaxasncp_dict.l"
BEGIN LOADING;
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 191 "wimaxasncp_dict.l"
BEGIN LOADING_XMLPI;
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 192 "wimaxasncp_dict.l"
;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 193 "wimaxasncp_dict.l"
{
	xmlpi = g_malloc(sizeof(wimaxasncp_dict_xmlpi_t));
	xmlpi->name = g_strdup(WimaxasncpDicttext);
	xmlpi->key = NULL;
	xmlpi->value = NULL;
	xmlpi->next = NULL;

	if (!dict->xmlpis) last_xmlpi = dict->xmlpis = xmlpi;
	else last_xmlpi = last_xmlpi->next = xmlpi;

	BEGIN XMLPI_ATTRS;
}
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 206 "wimaxasncp_dict.l"
BEGIN XMLPI_GETKEY;
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 207 "wimaxasncp_dict.l"
{ xmlpi->key = g_strdup(WimaxasncpDicttext); BEGIN XMLPI_ATTRS; }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 209 "wimaxasncp_dict.l"
BEGIN XMLPI_GETVAL;
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 210 "wimaxasncp_dict.l"
{ xmlpi->value = g_strdup(WimaxasncpDicttext); BEGIN XMLPI_ATTRS; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 212 "wimaxasncp_dict.l"

	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 213 "wimaxasncp_dict.l"
BEGIN LOADING;
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 216 "wimaxasncp_dict.l"
BEGIN ENTITY;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 217 "wimaxasncp_dict.l"
{
	entity_t *e = g_malloc(sizeof(entity_t));
	D(("ENTITY: %s\n",WimaxasncpDicttext));
	e->name = g_strdup(WimaxasncpDicttext);
	e->next = ents.next;
	ents.next = e;
	BEGIN GET_SYSTEM;
};
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 225 "wimaxasncp_dict.l"
BEGIN GET_FILE;
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 226 "wimaxasncp_dict.l"
{
	D(("GET_FILE: %s\n",WimaxasncpDicttext));
	ents.next->file = g_strdup(WimaxasncpDicttext);
	BEGIN END_ENTITY;
}
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 231 "wimaxasncp_dict.l"
BEGIN LOADING;
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 233 "wimaxasncp_dict.l"
APPEND("<",1);
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 235 "wimaxasncp_dict.l"
APPEND(">",1);
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 237 "wimaxasncp_dict.l"
APPEND("/>",2);
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 239 "wimaxasncp_dict.l"
APPEND("</",2);
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 241 "wimaxasncp_dict.l"
APPEND(" ",1);
	YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 243 "wimaxasncp_dict.l"
APPEND(WimaxasncpDicttext,WimaxasncpDictleng);
	YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 245 "wimaxasncp_dict.l"
APPEND("=",1);
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 247 "wimaxasncp_dict.l"
APPEND(WimaxasncpDicttext,WimaxasncpDictleng);
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 249 "wimaxasncp_dict.l"
{
	gchar *p = ++WimaxasncpDicttext, *temp_str;
	entity_t* e;

	while(*p != ';') p++;

	*p = '\0';

	D(("looking for entity: %s\n",WimaxasncpDicttext));

	if ( include_stack_ptr >= MAX_INCLUDE_DEPTH ) {
		dict_error = g_string_append(
			dict_error, "included files nested too deeply\n");
		yyterminate();
	}

	include_stack[include_stack_ptr++] = YY_CURRENT_BUFFER;


	for (e = ents.next; e; e = e->next) {
		if (strcmp(e->name,WimaxasncpDicttext) == 0) {
			WimaxasncpDictin = wimaxasncp_dict_open(sys_dir,e->file);
			D(("entity: %s filename: %s WimaxasncpDictin: %p\n",e->name,e->file,WimaxasncpDictin));
			if (!WimaxasncpDictin) {
				yyterminate();
			} else {
				WimaxasncpDict_switch_to_buffer(WimaxasncpDict_create_buffer(WimaxasncpDictin,YY_BUF_SIZE ) );
			}
			break;
		}
	}

	if (!e) {
		temp_str = g_strdup_printf(
			"cannot find entity: '%s'\n", e->name);
		dict_error = g_string_append(dict_error, temp_str);
		g_free(temp_str);
		yyterminate();
	}

}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(LOADING):
case YY_STATE_EOF(LOADING_COMMENT):
case YY_STATE_EOF(LOADING_XMLPI):
case YY_STATE_EOF(ENTITY):
case YY_STATE_EOF(GET_SYSTEM):
case YY_STATE_EOF(GET_FILE):
case YY_STATE_EOF(END_ENTITY):
case YY_STATE_EOF(GET_ATTR):
case YY_STATE_EOF(GET_UINT_ATTR):
case YY_STATE_EOF(GET_UINT16_ATTR):
case YY_STATE_EOF(BIT32):
case YY_STATE_EOF(BIT16):
case YY_STATE_EOF(BIT8):
case YY_STATE_EOF(GET_DECODER_ATTR):
case YY_STATE_EOF(END_ATTR):
case YY_STATE_EOF(OUTSIDE):
case YY_STATE_EOF(IN_DICT):
case YY_STATE_EOF(IN_APPL):
case YY_STATE_EOF(IN_TLV):
case YY_STATE_EOF(IGNORE_ATTR):
case YY_STATE_EOF(ENUM_ATTRS):
case YY_STATE_EOF(TLV_ATTRS):
case YY_STATE_EOF(XMLPI_ATTRS):
case YY_STATE_EOF(XMLPI_GETKEY):
case YY_STATE_EOF(XMLPI_GETVAL):
case YY_STATE_EOF(XMLPI_ENDATTR):
#line 291 "wimaxasncp_dict.l"
{
	if (!WimaxasncpDictin) yyterminate();

	fclose(WimaxasncpDictin);
	D(("closing: %p %i\n",WimaxasncpDictin,include_stack_ptr));

	if ( --include_stack_ptr < 0 ) {
		D(("DONE READING\n"));
		WimaxasncpDictin = NULL;
		yyterminate();
	} else {
		WimaxasncpDict_delete_buffer(YY_CURRENT_BUFFER );
		WimaxasncpDict_switch_to_buffer(include_stack[include_stack_ptr]);
		BEGIN LOADING;
	}
}
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 309 "wimaxasncp_dict.l"
{
	*attr_str = g_strdup(WimaxasncpDicttext);
	D(("%s\n",WimaxasncpDicttext));
	attr_str = NULL;
	BEGIN END_ATTR;
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 316 "wimaxasncp_dict.l"
{
	*attr_uint = strtoul(WimaxasncpDicttext,NULL,0);
	D(("%s\n",WimaxasncpDicttext););
	attr_uint = NULL;
	BEGIN END_ATTR;
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 323 "wimaxasncp_dict.l"
{
	*attr_uint16 = (gint16) strtol(WimaxasncpDicttext,NULL,0);
	D(("%s\n",WimaxasncpDicttext););
	attr_uint16 = NULL;
	BEGIN END_ATTR;
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 330 "wimaxasncp_dict.l"
{ BEGIN BIT32; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 332 "wimaxasncp_dict.l"
{
	*attr_uint = wimaxasncp_bits(32, WimaxasncpDicttext);
	D(("WIMAXASNCP_BIT32(%s)\n",WimaxasncpDicttext););
	attr_uint = NULL;
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 338 "wimaxasncp_dict.l"
{ BEGIN BIT16; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 340 "wimaxasncp_dict.l"
{
	*attr_uint = wimaxasncp_bits(16, WimaxasncpDicttext);
	D(("WIMAXASNCP_BIT16(%s)\n",WimaxasncpDicttext););
	attr_uint = NULL;
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 346 "wimaxasncp_dict.l"
{ BEGIN BIT8; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 348 "wimaxasncp_dict.l"
{
	*attr_uint = wimaxasncp_bits(8, WimaxasncpDicttext);
	D(("WIMAXASNCP_BIT8(%s)\n",WimaxasncpDicttext););
	attr_uint = NULL;
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 354 "wimaxasncp_dict.l"
{ BEGIN END_ATTR; }
	YY_BREAK
case 39:
/* rule 39 can match eol */
YY_RULE_SETUP
#line 356 "wimaxasncp_dict.l"
{
	*attr_uint = wimaxasncp_decode_type(WimaxasncpDicttext);
	D(("%s\n",WimaxasncpDicttext));
	attr_uint = NULL;
	BEGIN END_ATTR;
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 363 "wimaxasncp_dict.l"
{	yy_pop_state(); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 365 "wimaxasncp_dict.l"
{
	/* XXX: should go?*/
	D(("{%s}",WimaxasncpDicttext));
}
	YY_BREAK
case 42:
/* rule 42 can match eol */
YY_RULE_SETUP
#line 370 "wimaxasncp_dict.l"
{
	D(("=>%s<=\n",WimaxasncpDicttext));
	yy_pop_state();
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 375 "wimaxasncp_dict.l"
{
	D(("dictionary_start\n"));

	BEGIN IN_DICT;
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 381 "wimaxasncp_dict.l"
{
	D(("tlv_start\n"));

	tlv = g_malloc(sizeof(wimaxasncp_dict_tlv_t));
	tlv->type = 0;
	tlv->name = NULL;
	tlv->description = NULL;
	tlv->decoder = 0;
	tlv->hf_root = -1;
	tlv->hf_value = -1;
	tlv->hf_ipv4 = -1;
	tlv->hf_ipv6 = -1;
	tlv->hf_bsid = -1;
	tlv->hf_protocol = -1;
	tlv->hf_port_low = -1;
	tlv->hf_port_high = -1;
	tlv->hf_ipv4_mask = -1;
	tlv->hf_ipv6_mask = -1;
	tlv->hf_vendor_id = -1;
	tlv->hf_vendor_rest_of_info = -1;
	tlv->enum_vs = NULL;
	tlv->enums = NULL;
	tlv->next = NULL;

	if (! dict->tlvs ) last_tlv = dict->tlvs = tlv;
	else last_tlv = last_tlv->next = tlv;

	BEGIN TLV_ATTRS;
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 411 "wimaxasncp_dict.l"
{ ATTR_STR(tlv->name); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 412 "wimaxasncp_dict.l"
{ ATTR_STR(tlv->description); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 413 "wimaxasncp_dict.l"
{ ATTR_UINT16(tlv->type); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 414 "wimaxasncp_dict.l"
{ ATTR_DECODER(tlv->decoder); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 415 "wimaxasncp_dict.l"
{ BEGIN IN_TLV;	 }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 416 "wimaxasncp_dict.l"
{ BEGIN IN_DICT; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 419 "wimaxasncp_dict.l"
{
	D(("enum_start\n"));

	enumitem = g_malloc(sizeof(wimaxasncp_dict_enum_t));
	enumitem->name = NULL;
	enumitem->code = 0;
	enumitem->next = NULL;

	if (!tlv->enums) last_enumitem = tlv->enums = enumitem;
	else last_enumitem = last_enumitem->next = enumitem;

	BEGIN ENUM_ATTRS;
}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 434 "wimaxasncp_dict.l"
{ ATTR_STR(enumitem->name); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 435 "wimaxasncp_dict.l"
{ ATTR_UINT(enumitem->code); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 437 "wimaxasncp_dict.l"
{ BEGIN IN_TLV; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 438 "wimaxasncp_dict.l"
{ BEGIN IN_TLV; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 440 "wimaxasncp_dict.l"
{ D(("tlv_end")); BEGIN IN_DICT; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 442 "wimaxasncp_dict.l"
{
	yyterminate();
}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 446 "wimaxasncp_dict.l"
WIMAXASNCP_IGNORE();
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 448 "wimaxasncp_dict.l"
;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 455 "wimaxasncp_dict.l"
ECHO;
	YY_BREAK
#line 1772 "wimaxasncp_dict.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed WimaxasncpDictin at a new source and called
			 * WimaxasncpDictlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = WimaxasncpDictin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( WimaxasncpDictwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * WimaxasncpDicttext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of WimaxasncpDictlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					WimaxasncpDictrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			WimaxasncpDictrestart(WimaxasncpDictin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) WimaxasncpDictrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 326 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 326 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 325);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					WimaxasncpDictrestart(WimaxasncpDictin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( WimaxasncpDictwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve WimaxasncpDicttext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void WimaxasncpDictrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        WimaxasncpDictensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            WimaxasncpDict_create_buffer(WimaxasncpDictin,YY_BUF_SIZE );
	}

	WimaxasncpDict_init_buffer(YY_CURRENT_BUFFER,input_file );
	WimaxasncpDict_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void WimaxasncpDict_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		WimaxasncpDictpop_buffer_state();
	 *		WimaxasncpDictpush_buffer_state(new_buffer);
     */
	WimaxasncpDictensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	WimaxasncpDict_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (WimaxasncpDictwrap()) processing, but the only time this flag
	 * is looked at is after WimaxasncpDictwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void WimaxasncpDict_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	WimaxasncpDictin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE WimaxasncpDict_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) WimaxasncpDictalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in WimaxasncpDict_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) WimaxasncpDictalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in WimaxasncpDict_create_buffer()" );

	b->yy_is_our_buffer = 1;

	WimaxasncpDict_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with WimaxasncpDict_create_buffer()
 * 
 */
    void WimaxasncpDict_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		WimaxasncpDictfree((void *) b->yy_ch_buf  );

	WimaxasncpDictfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a WimaxasncpDictrestart() or at EOF.
 */
    static void WimaxasncpDict_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	WimaxasncpDict_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then WimaxasncpDict_init_buffer was _probably_
     * called from WimaxasncpDictrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void WimaxasncpDict_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		WimaxasncpDict_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void WimaxasncpDictpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	WimaxasncpDictensure_buffer_stack();

	/* This block is copied from WimaxasncpDict_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from WimaxasncpDict_switch_to_buffer. */
	WimaxasncpDict_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void WimaxasncpDictpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	WimaxasncpDict_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		WimaxasncpDict_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void WimaxasncpDictensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)WimaxasncpDictalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in WimaxasncpDictensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)WimaxasncpDictrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in WimaxasncpDictensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE WimaxasncpDict_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) WimaxasncpDictalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in WimaxasncpDict_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	WimaxasncpDict_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to WimaxasncpDictlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       WimaxasncpDict_scan_bytes() instead.
 */
YY_BUFFER_STATE WimaxasncpDict_scan_string (yyconst char * yystr )
{
    
	return WimaxasncpDict_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to WimaxasncpDictlex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE WimaxasncpDict_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) WimaxasncpDictalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in WimaxasncpDict_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = WimaxasncpDict_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in WimaxasncpDict_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) WimaxasncpDictalloc(new_size  );

		else
			(yy_start_stack) = (int *) WimaxasncpDictrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    static int yy_top_state  (void)
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up WimaxasncpDicttext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		WimaxasncpDicttext[WimaxasncpDictleng] = (yy_hold_char); \
		(yy_c_buf_p) = WimaxasncpDicttext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		WimaxasncpDictleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int WimaxasncpDictget_lineno  (void)
{
        
    return WimaxasncpDictlineno;
}

/** Get the input stream.
 * 
 */
FILE *WimaxasncpDictget_in  (void)
{
        return WimaxasncpDictin;
}

/** Get the output stream.
 * 
 */
FILE *WimaxasncpDictget_out  (void)
{
        return WimaxasncpDictout;
}

/** Get the length of the current token.
 * 
 */
int WimaxasncpDictget_leng  (void)
{
        return WimaxasncpDictleng;
}

/** Get the current token.
 * 
 */

char *WimaxasncpDictget_text  (void)
{
        return WimaxasncpDicttext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void WimaxasncpDictset_lineno (int  line_number )
{
    
    WimaxasncpDictlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see WimaxasncpDict_switch_to_buffer
 */
void WimaxasncpDictset_in (FILE *  in_str )
{
        WimaxasncpDictin = in_str ;
}

void WimaxasncpDictset_out (FILE *  out_str )
{
        WimaxasncpDictout = out_str ;
}

int WimaxasncpDictget_debug  (void)
{
        return WimaxasncpDict_flex_debug;
}

void WimaxasncpDictset_debug (int  bdebug )
{
        WimaxasncpDict_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from WimaxasncpDictlex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    WimaxasncpDictin = stdin;
    WimaxasncpDictout = stdout;
#else
    WimaxasncpDictin = (FILE *) 0;
    WimaxasncpDictout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * WimaxasncpDictlex_init()
     */
    return 0;
}

/* WimaxasncpDictlex_destroy is for both reentrant and non-reentrant scanners. */
int WimaxasncpDictlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		WimaxasncpDict_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		WimaxasncpDictpop_buffer_state();
	}

	/* Destroy the stack itself. */
	WimaxasncpDictfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        WimaxasncpDictfree((yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * WimaxasncpDictlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *WimaxasncpDictalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *WimaxasncpDictrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void WimaxasncpDictfree (void * ptr )
{
	free( (char *) ptr );	/* see WimaxasncpDictrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 455 "wimaxasncp_dict.l"



static int debugging  = 0;

static void wimaxasncp_dict_debug(const gchar *fmt, ...) {
	va_list ap;

	va_start(ap, fmt);
	if (debugging) vfprintf(stderr, fmt, ap);
	va_end(ap);

	fflush(stderr);
}

static guint wimaxasncp_bits(guint bits, char *n)
{
	return 1 << ((bits - 1) - (strtoul(n, NULL, 10)));
}

static const value_string wimaxasncp_decode_type_vals[] =
{
  { WIMAXASNCP_TLV_TBD,                 "WIMAXASNCP_TLV_TBD"},
  { WIMAXASNCP_TLV_COMPOUND,            "WIMAXASNCP_TLV_COMPOUND"},
  { WIMAXASNCP_TLV_BYTES,               "WIMAXASNCP_TLV_BYTES"},
  { WIMAXASNCP_TLV_ENUM8,               "WIMAXASNCP_TLV_ENUM8"},
  { WIMAXASNCP_TLV_ENUM16,              "WIMAXASNCP_TLV_ENUM16"},
  { WIMAXASNCP_TLV_ENUM32,              "WIMAXASNCP_TLV_ENUM32"},
  { WIMAXASNCP_TLV_ETHER,               "WIMAXASNCP_TLV_ETHER"},
  { WIMAXASNCP_TLV_ASCII_STRING,        "WIMAXASNCP_TLV_ASCII_STRING"},
  { WIMAXASNCP_TLV_FLAG0,               "WIMAXASNCP_TLV_FLAG0"},
  { WIMAXASNCP_TLV_BITFLAGS8,           "WIMAXASNCP_TLV_BITFLAGS8"},  
  { WIMAXASNCP_TLV_BITFLAGS16,          "WIMAXASNCP_TLV_BITFLAGS16"},
  { WIMAXASNCP_TLV_BITFLAGS32,          "WIMAXASNCP_TLV_BITFLAGS32"},
  { WIMAXASNCP_TLV_ID,                  "WIMAXASNCP_TLV_ID"},
  { WIMAXASNCP_TLV_HEX8,                "WIMAXASNCP_TLV_HEX8"},
  { WIMAXASNCP_TLV_HEX16,               "WIMAXASNCP_TLV_HEX16"},
  { WIMAXASNCP_TLV_HEX32,               "WIMAXASNCP_TLV_HEX32"},
  { WIMAXASNCP_TLV_DEC8,                "WIMAXASNCP_TLV_DEC8"},
  { WIMAXASNCP_TLV_DEC16,               "WIMAXASNCP_TLV_DEC16"},
  { WIMAXASNCP_TLV_DEC32,               "WIMAXASNCP_TLV_DEC32"},
  { WIMAXASNCP_TLV_IP_ADDRESS,          "WIMAXASNCP_TLV_IP_ADDRESS"},
  { WIMAXASNCP_TLV_IPV4_ADDRESS,        "WIMAXASNCP_TLV_IPV4_ADDRESS"},
  { WIMAXASNCP_TLV_PROTOCOL_LIST,       "WIMAXASNCP_TLV_PROTOCOL_LIST"},
  { WIMAXASNCP_TLV_PORT_RANGE_LIST,     "WIMAXASNCP_TLV_PORT_RANGE_LIST"},
  { WIMAXASNCP_TLV_IP_ADDRESS_MASK_LIST,"WIMAXASNCP_TLV_IP_ADDRESS_MASK_LIST"},
  { WIMAXASNCP_TLV_EAP,                 "WIMAXASNCP_TLV_EAP"},
  { WIMAXASNCP_TLV_VENDOR_SPECIFIC,     "WIMAXASNCP_TLV_VENDOR_SPECIFIC"},
  { 0, NULL}
};

static gint wimaxasncp_decode_type(const gchar *name)
{
	gsize i;
	for (i = 0; i < array_length(wimaxasncp_decode_type_vals) - 1; ++i)
	{
		if (strcmp(name, wimaxasncp_decode_type_vals[i].strptr) == 0)
		{
			return wimaxasncp_decode_type_vals[i].value;
		}
	}

	/* not found, emit some sort of error here? */

	return WIMAXASNCP_TLV_TBD;
}

static gchar *strbuf = NULL;
static gchar *write_ptr = NULL;
static gchar *read_ptr = NULL;

static guint size_strbuf = 8192;
static guint len_strbuf = 0;

extern void wimaxasncp_dict_unused(void);
void wimaxasncp_dict_unused(void) {
	yy_top_state();
}

static void append_to_buffer(gchar *txt, int len) {

	if (strbuf == NULL) {
		read_ptr = write_ptr = strbuf = g_malloc(size_strbuf);
	}

	if ( (len_strbuf + len + 1) >= size_strbuf ) {
		read_ptr = strbuf = g_realloc(strbuf,size_strbuf *= 2);
	}

	write_ptr = strbuf + len_strbuf;
	strncpy(write_ptr,txt,len);
	len_strbuf += len;
	strbuf[len_strbuf] = '\0';
}

static size_t file_input(gchar *buf, size_t max) {
	size_t read;

	read = fread(buf,1,max,WimaxasncpDictin);

	if ( read == max ) {
		return max;
	} else if (read > 0) {
		return read;
	} else {
		return YY_NULL;
	}
}


static size_t string_input(gchar *buf, size_t max) {
	if (read_ptr >= write_ptr ) {
		return YY_NULL;
	} else if ( read_ptr + max > write_ptr ) {
		max = write_ptr - read_ptr;
	}

	memcpy(buf,read_ptr,max);
	read_ptr += max;

	return max;
}

static FILE *wimaxasncp_dict_open(
	const gchar *system_directory,
	const gchar *filename)
{
	FILE *fh;
	gchar *fname;
	if (system_directory)
	{
		int len =  strlen(system_directory) + strlen(filename)
			+ strlen(G_DIR_SEPARATOR_S) + 1;
		fname = g_malloc(len);
		g_snprintf(fname, len, "%s%s%s",
			   system_directory, G_DIR_SEPARATOR_S,filename);
	}
	else
	{
		fname = g_strdup(filename);
	}

	fh = ws_fopen(fname,"r");

	D(("fname: %s fh: %p\n",fname,fh));

	g_free(fname);


	return fh;
}

wimaxasncp_dict_t *wimaxasncp_dict_scan(
	const gchar *system_directory, const gchar *filename, int dbg,
	gchar **error) {

	entity_t *e;

	dict_error = g_string_new("");

	debugging = dbg;

	sys_dir = system_directory;

	write_ptr = NULL;
	read_ptr = NULL;

	if (dict)
	{
		wimaxasncp_dict_free(dict);
	}

	dict = g_malloc(sizeof(wimaxasncp_dict_t));
	dict->tlvs = NULL;
	dict->xmlpis = NULL;

	tlv = NULL;
	enumitem = NULL;
	xmlpi = NULL;

	last_tlv = NULL;
	last_enumitem = NULL;
	last_xmlpi = NULL;

	ents.next = NULL;

	WimaxasncpDictin = wimaxasncp_dict_open(sys_dir,filename);

	if (WimaxasncpDictin)
	{
		current_yyinput = file_input;
		BEGIN LOADING;
		WimaxasncpDictlex();

		D(("\n---------------\n%s\n------- %d -------\n",
		   strbuf, len_strbuf));

		current_yyinput = string_input;

		BEGIN OUTSIDE;
		WimaxasncpDictlex();
	}

	e = ents.next;
	while (e)
	{
		entity_t *next = e->next;
		g_free(e->name);
		g_free(e->file);
		g_free(e);
		e = next;
	}

	g_free(strbuf);
	strbuf = NULL;
	size_strbuf = 8192;

	if (dict_error->len > 0)
	{
		*error = dict_error->str;
		g_string_free(dict_error, FALSE);
	}
	else
	{
		*error = NULL;
		g_string_free(dict_error, TRUE);
	}

	return dict;
}

void wimaxasncp_dict_free(wimaxasncp_dict_t *d) {
	wimaxasncp_dict_tlv_t *t, *tn;

#define FREE_NAMEANDOBJ(n) do { if(n->name) g_free(n->name); g_free(n); } while(0)

	for (t = d->tlvs; t; t = tn) {
		wimaxasncp_dict_enum_t *e, *en;
		tn = t->next;

		for (e = t->enums; e; e = en) {
			en = e->next;
			FREE_NAMEANDOBJ(e);
		}

		if (!t->description)  g_free(t->description);
		FREE_NAMEANDOBJ(t);
	}

	g_free(d);
}

void wimaxasncp_dict_print(FILE *fh, wimaxasncp_dict_t *d) {
	wimaxasncp_dict_tlv_t *tlv;

	fprintf(fh,"\n");

	for (tlv = d->tlvs; tlv; tlv = tlv->next) {
		wimaxasncp_dict_enum_t *e;
		fprintf(fh,"TLV: %s[%u] %s[%d] %s\n",
				tlv->name ? tlv->name : "-",
				tlv->type,
				val_to_str(tlv->decoder,
					   wimaxasncp_decode_type_vals,
					   "Unknown"),
				tlv->decoder,
				tlv->description ? tlv->description : "");

		for (e = tlv->enums; e; e = e->next) {
			fprintf(fh,"\tEnum: %s[%u]\n",
					e->name ? e->name : "-",
					e->code);
		}
	}
}

/*
 * We want to stop processing when we get to the end of the input.
 * (%option noyywrap is not used because if used then
 * some flex versions (eg: 2.5.35) generate code which causes
 * warnings by the Windows VC compiler).
 */

int WimaxasncpDictwrap(void) {
    return 1;
}

#ifdef TEST_WIMAXASNCP_DICT_STANDALONE
int main(int argc, char **argv) {
	wimaxasncp_dict_t *d;
	gchar *dname = NULL;
	gchar *fname;
	int i = 1;

	switch (argc) {
		case 3:
			dname = argv[i++];
		case 2:
			fname = argv[i];
			break;
		default:
			fprintf(stderr,"%s: usage [dictionary_dir] dictionary_filename\n",argv[0]);
			return 1;
	}

	d = wimaxasncp_dict_scan(dname,fname,1,&dict_error);

	if (dict_error)
	{
		printf("wimaxasncp - %s", dict_error);
		g_free(dict_error);
	}

	wimaxasncp_dict_print(stdout, d);

	return 0;
}
#endif

